@@ -4,9 +4,9 @@ from cms.apphook_pool import apphook_pool
 from django.utils.translation import gettext as _
 
 
-class AutomationsApphook (CMSApp):
+class AutomationsApphook(CMSApp):
     name = _("Django Automations")
-    app_name = 'automations'
+    app_name = "automations"
 
     def get_urls(self, page=None, langague=None, **kwargs):
         return ["automations.urls"]
