@@ -15,6 +15,7 @@ from . import models as cms_models
 logger = logging.getLogger(__name__)
 
 
+@plugin_pool.register_plugin
 class AutomationTaskList(CMSPluginBase):
     name = _("Task list")
     module = _("Automations")
@@ -32,9 +33,7 @@ class AutomationTaskList(CMSPluginBase):
         return context
 
 
-plugin_pool.register_plugin(AutomationTaskList)
-
-
+@plugin_pool.register_plugin
 class AutomationDashboard(CMSPluginBase):
     name = _("Dashboard")
     module = _("Automations")
@@ -48,9 +47,6 @@ class AutomationDashboard(CMSPluginBase):
         return context
 
 
-plugin_pool.register_plugin(AutomationDashboard)
-
-
 def get_task_choices(pattern, convert, subclass=None):
     status_choices = []
     for cls_name, verbose_name in flow.get_automations():
@@ -132,7 +128,7 @@ class EditTaskData(forms.ModelForm):
 
     def clean_name(self):
         choices = {}
-        for _, chapter in get_task_status_choices():
+        for __, chapter in get_task_status_choices():
             choices.update({key: value for key, value in chapter})
         return choices.get(self.data["template"], "")
 
