@@ -92,8 +92,23 @@ class Node:
         self._skipif = []
         self._skipafter = None
         self._leave = False
+        self._model_defaults = dict(locked=0)
         self.description = kwargs.pop("description", "")
 
+    def modifiers(self):
+        mods = []
+        if self._conditions:
+            mods.append("If")
+        if self._next:
+            mods.append("Next")
+        if self._wait:
+            mods.append("Wait")
+        if self._skipif:
+            mods.append("SkipIf")
+        if self._skipafter:
+            mods.append("SkipAfter")
+        return mods
+
     @staticmethod
     def eval(sth, task):
         return sth(task) if callable(sth) else sth
@@ -140,9 +155,7 @@ class Node:
         task, _ = db.automationtaskmodel_set.get_or_create(
             previous=prev_task,
             status=self._name,
-            defaults=dict(
-                locked=0,
-            ),
+            defaults=self._model_defaults,
         )
         self._leave = False
         if task.locked > 0:
@@ -180,6 +193,17 @@ class Node:
                 raise ImproperlyConfigured(f"No End() node after {self._name}")
             return next_node
 
+    def pause_automation(self, earliest_execution):
+        if (
+            self._automation._db.paused_until
+            and self._automation._db.paused_until >= now()
+        ):
+            self._automation._db.paused_until = min(
+                self._automation._db.paused_until, earliest_execution
+            )
+        else:
+            self._automation._db.paused_until = earliest_execution
+
     @on_execution_path
     def when_handler(self, task):
         for condition in self._conditions:
@@ -194,12 +218,7 @@ class Node:
         earliest_execution = self.eval(self._wait, task)
         if earliest_execution < now():
             return task
-        if self._automation._db.paused_until:
-            self._automation._db.paused_until = min(
-                self._automation._db.paused_until, earliest_execution
-            )
-        else:
-            self._automation._db.paused_until = earliest_execution
+        self.pause_automation(earliest_execution)
         self._automation._db.save()
         return self.release_lock(task)
 
@@ -210,7 +229,7 @@ class Node:
             task.message = "skipped"
             self.release_lock(task)
             self._leave = True
-            return None
+            return self.release_lock(task)
 
         if self._skipafter is not None:
             latest_execution = task.created + self.eval(self._skipafter, task)
@@ -542,10 +561,20 @@ class If(Execute):
 
 class Form(Node):
     def __init__(
-        self, form, template_name=None, context=None, repeated_form=False, **kwargs
+        self,
+        form,
+        template_name=None,
+        context=None,
+        repeated_form=False,
+        success_url=None,
+        **kwargs,
     ):
         super().__init__(**kwargs)
+        self._model_defaults = dict(
+            locked=-1, requires_interaction=True
+        )  # Start w/o lock, but interaction needed
         self._form = form
+        self._success_url = success_url
         self._context = context if context is not None else {}
         self._repeated_form = repeated_form
         self._template_name = template_name
@@ -565,15 +594,9 @@ class Form(Node):
                 )
             task.interaction_user = self.get_user()
             task.interaction_group = self.get_group()
-            if (
-                self._repeated_form
-                or task.data.get(f"_{self._name}_validated", None) is None
-            ):
-                task.requires_interaction = True
-                self.release_lock(
-                    task
-                )  # Release lock and stop automation until form is validated
-                return None
+
+            if task.requires_interaction:  # Not yet validated -> pause
+                return self.release_lock(task)
         return task  # Continue with validated form
 
     def is_valid(self, task: models.AutomationTaskModel, request, form):
@@ -582,7 +605,6 @@ class Form(Node):
         )
         task.automation.save()
         task.requires_interaction = False
-        task.finished = now()
         task.save()
 
     def User(self, **kwargs):
