@@ -192,11 +192,9 @@ class AutomationTaskModel(models.Model):
 
     @classmethod
     def get_open_tasks(cls, user):
-        candidates = cls.objects.filter(finished=None)
+        candidates = cls.objects.filter(finished=None, requires_interaction=True)
         return tuple(
-            task
-            for task in candidates
-            if task.requires_interaction and user in task.get_users_with_permission()
+            task for task in candidates if user in task.get_users_with_permission()
         )
 
     def get_users_with_permission(
